@@ -452,6 +452,8 @@ _OptionalCreateDBInstanceMessageRequestTypeDef = TypedDict(
         "AutoMinorVersionUpgrade": bool,
         "Tags": Sequence["TagTypeDef"],
         "PromotionTier": int,
+        "EnablePerformanceInsights": bool,
+        "PerformanceInsightsKMSKeyId": str,
     },
     total=False,
 )
@@ -1640,6 +1642,8 @@ _OptionalModifyDBInstanceMessageRequestTypeDef = TypedDict(
         "NewDBInstanceIdentifier": str,
         "CACertificateIdentifier": str,
         "PromotionTier": int,
+        "EnablePerformanceInsights": bool,
+        "PerformanceInsightsKMSKeyId": str,
     },
     total=False,
 )
