@@ -1,7 +1,7 @@
 """
 Type annotations for docdb service client waiters.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_docdb/waiters.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/waiters/)
 
 Usage::
 
@@ -33,7 +33,7 @@ __all__ = ("DBInstanceAvailableWaiter", "DBInstanceDeletedWaiter")
 class DBInstanceAvailableWaiter(Boto3Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_docdb/waiters.html#dbinstanceavailablewaiter)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/waiters/#dbinstanceavailablewaiter)
     """
 
     def wait(
@@ -43,18 +43,18 @@ class DBInstanceAvailableWaiter(Boto3Waiter):
         Filters: Sequence["FilterTypeDef"] = ...,
         MaxRecords: int = ...,
         Marker: str = ...,
-        WaiterConfig: WaiterConfigTypeDef = ...
+        WaiterConfig: "WaiterConfigTypeDef" = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable.wait)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_docdb/waiters.html#dbinstanceavailablewaiter)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/waiters/#dbinstanceavailablewaiter)
         """
 
 
 class DBInstanceDeletedWaiter(Boto3Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_docdb/waiters.html#dbinstancedeletedwaiter)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/waiters/#dbinstancedeletedwaiter)
     """
 
     def wait(
@@ -64,9 +64,9 @@ class DBInstanceDeletedWaiter(Boto3Waiter):
         Filters: Sequence["FilterTypeDef"] = ...,
         MaxRecords: int = ...,
         Marker: str = ...,
-        WaiterConfig: WaiterConfigTypeDef = ...
+        WaiterConfig: "WaiterConfigTypeDef" = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted.wait)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_docdb/waiters.html#dbinstancedeletedwaiter)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/waiters/#dbinstancedeletedwaiter)
         """
